package com.ruixuan.isc.controller;

import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.PageInfo;
import com.ruixuan.common.constant.HttpStatus;
import com.ruixuan.common.core.controller.BaseController;
import com.ruixuan.common.core.page.TableDataInfo;
import com.ruixuan.common.utils.Check;
import com.ruixuan.common.utils.DateUtils;
import com.ruixuan.isc.entity.KuaishouAccessToken;
import com.ruixuan.isc.entity.KuaishouRewardBaseInfo;
import com.ruixuan.isc.entity.KwaixiaodianItemGet;
import com.ruixuan.isc.service.IAccessTokenService;
import com.ruixuan.isc.service.IKwaixiaodianItemGetService;
import com.ruixuan.isc.service.IKwaixiaodianOrderCursorListService;
import com.ruixuan.system.service.ISysDeptService;
import com.ruixuan.system.service.ISysRoleService;
import com.ruixuan.system.service.ISysUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.models.auth.In;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.*;

/**
 * kwaixiaodian商品详情Controller
 *
 * @date 2024-10-28
 */
@Api(tags = "Kwaixiaodian")
@RestController
@RequestMapping("/kwaixiaodian/item")
@Slf4j
public class KwaixiaodianItemGetController extends BaseController {
    @Autowired
    private IKwaixiaodianItemGetService kwaixiaodianItemGetService;

    @Autowired
    private IKwaixiaodianOrderCursorListService orderCursorListService;
    @Autowired
    private IAccessTokenService accessTokenService;
    @Autowired
    private ISysRoleService sysRoleService;
    @Autowired
    private ISysDeptService sysDeptService;
    @Autowired
    private ISysUserService sysUserService;

    @GetMapping("/list")
    public TableDataInfo list(Long itemId, String title, Integer itemType, Long userId) {
        TableDataInfo rspData = new TableDataInfo();
        try {
            if (Check.isNull(userId)) {
                throw new Exception("请传入用户ID");
            }
            Map<String, Object> requestMap = new HashMap<>();

            String roleId = sysRoleService.getRoleBYUserId(userId);
            if ("admin".equals(roleId)) { // 管理员查看所有

            } else if ("industry_admin".equals(roleId)) { // 供应链管理员查看所属公司
                Long companyId = kwaixiaodianItemGetService.getCompanyId(userId);
                if (Check.isNull(companyId)) {
                    throw new Exception("此用户未查询到归属公司");
                }
                requestMap.put("companyId", companyId);
            } else if ("industry_sale_manager".equals(roleId) || "industry_courtship_manager".equals(roleId) || "industry_purchase_manager".equals(roleId)) { // 经理角色查看部门下所有成员数据
                List<Long> userIds = kwaixiaodianItemGetService.getUserIds(userId);
                if (Check.isNull(userIds)) {
                    throw new Exception("此用户未查询到部门成员信息");
                }
                requestMap.put("userIds", userIds);
            } else if ("industry_sale".equals(roleId) || "industry_purchase".equals(roleId) || "industry_courtship".equals(roleId)) { // 销售  采购 招商 查看自己的数据
                List<Long> userIds = new ArrayList<>();
                userIds.add(userId);
                requestMap.put("userIds", userIds);
            }
            if (!Check.isNull(itemId)) {
                requestMap.put("itemId", itemId);
            }
            if (!Check.isNull(title)) {
                requestMap.put("title", title);
            }
            if (!Check.isNull(itemType)) {
                requestMap.put("itemType", itemType);
            }


            startPage();
            List<KwaixiaodianItemGet> list = kwaixiaodianItemGetService.getItemList(requestMap);
            rspData.setCode(HttpStatus.SUCCESS);
            rspData.setMsg("查询成功");
            rspData.setRows(list);
            rspData.setTotal(new PageInfo(list).getTotal());
        } catch (Exception e) {
            e.printStackTrace();
            rspData.setCode(HttpStatus.ERROR);
            rspData.setMsg(e.getMessage());
        }
        return rspData;
    }


    /**
     * 获取商品详情（open.item.get)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.item.get&version=1
     */
    @GetMapping("/querykwaiItmInfo")
    @ApiOperation(value = "获kwai商品详情")
    public JSONObject querykwaiItmInfo(@ApiParam("商品ID") @RequestParam(value = "itemId", required = false) Long itemId, @ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId, @ApiParam("用户ID") @RequestParam(value = "userId", required = false) Long userId, @ApiParam("用户") @RequestParam(value = "userName", required = false) String userName, @ApiParam("用户") @RequestParam(value = "itemType", required = false) Integer itemType) {

        JSONObject returnJson = new JSONObject();
        try {
            KuaishouAccessToken token = accessTokenService.getKWaiAccessToken(shopId);
            if (Check.isNull(token)) {
                throw new Exception("未获取到授权信息，请联系管理员");
            }
            Long companyId = token.getCompanyId();
            Integer count = kwaixiaodianItemGetService.checkItem(companyId, itemId);
            if (count >= 1) {
                throw new Exception("此商品已绑定");
            }

            JSONObject jsonObject = kwaixiaodianItemGetService.querykwaiItmInfo(token, itemId, shopId, userId, userName, itemType);
            if (jsonObject.getBoolean("success")) {
                returnJson.put("code", 200);
                returnJson.put("message", "新增商品成功");
            } else {
                returnJson.put("code", 500);
                returnJson.put("message", jsonObject.getString("message"));
            }

        } catch (Exception e) {
            e.printStackTrace();
            returnJson.put("code", 500);
            returnJson.put("message", e.getMessage());
        }
        return returnJson;
    }

    /**
     * 获取订单列表（open.order.cursor.list)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.order.cursor.list&version=1
     */
    @GetMapping("/querykwaiOrderList")
    @ApiOperation(value = "获kwai订单列表")
    public void querykwaiOrderList(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId, @ApiParam("1按创建时间查找 2按更新时间查找") @RequestParam(value = "queryType", required = false) Integer queryType, @ApiParam("开始日期") @RequestParam(value = "beginDate", required = false) String beginDate, @ApiParam("结束日期（间隔不大于7天）") @RequestParam(value = "endDate", required = false) String endDate

    ) {
        try {
            orderCursorListService.querykwaiOrderList(shopId.trim(), queryType, beginDate, endDate, "");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @GetMapping("/queryNowdayKWaiOrderList")
    @ApiOperation(value = "获当天kwai订单")
    public void queryNowdayKWaiOrderList(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId) {
        try {
            orderCursorListService.queryNowdayKWaiOrderList(shopId.trim(), "");
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 获取订单列表（open.order.cursor.list)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.order.cursor.list&version=1
     */
    @GetMapping("/querykwaiOrderListMonth")
    @ApiOperation(value = "获kwai订单列表月度数据")
    public void querykwaiOrderListMonth(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId) {
        String date1 = DateUtils.getDate();
        String date0 = DateUtils.getSubtractTime(new Date(), 89);
        List<String> allDatesOfTwoTimes = DateUtils.getAllDatesOfTwoTimes(date0, date1);
        for (String date : allDatesOfTwoTimes) {
            orderCursorListService.querykwaiOrderList(shopId.trim(), 1, date, date, "");
            logger.info("shopId:{},日期：{} 执行-----ok", shopId, date);
        }
    }

    /**
     * 获取带货口碑分信息（open.score.master.get)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.score.master.get&version=1
     */
    @GetMapping("/queryMasterScore")
    @ApiOperation(value = "获取带货口碑分信息")
    public void queryMasterScore(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId) {
        orderCursorListService.queryMaster(shopId);
    }

    /**
     * 获取店铺体验分信息（open.score.shop.get)
     * https://open.kwaixiaodian.com/zone/new/docs/api?name=open.score.master.get&version=1
     */
    @GetMapping("/queryShopScore")
    @ApiOperation(value = "获取店铺体验分信息")
    public void queryShopScore(@ApiParam("店铺ID") @RequestParam(value = "shopId", required = false) String shopId) {
        orderCursorListService.queryShop(shopId);
    }

    public static void main(String[] args) {
        String date0 = DateUtils.getDate();
        String date1 = DateUtils.getSubtractTime(new Date(), 30);

        System.out.println(date0);
        System.out.println(date1);
    }
}
